@@ -415,6 +415,7 @@ char mdi[], mzi[], mdj[], mzj[];
     if(strncmp(mdi+1, "should ", 7) == 0) return;
     if(strncmp(mdi+1, "would ", 6) == 0) return;
     if(strncmp(mdi+1, "almost ", 7) == 0) return;
+    if(strncmp(mdi+1, "there are", 9) == 0) return;
     if(strncmp(mdi+1, "there be", 8) == 0 ){
       if(strstr(mzj, "") ){
 	ptreplace(mdi+7, 2, "are");    return;
@@ -607,6 +608,10 @@ char md[];
       if(pt = (char*)strchr(pt+1, ' '));
       else return;
     }
+ if(Dbg == 'Y') fprintf(dbg, "--- sinko --- md = %s pt = %s \n", md, pt);
+    if(strncmp(md+1, "be", 2) == 0 && pt-3 == md){
+      ptinsert(pt, "ing");  return;
+    }
     if(strncmp(pt-3, "lie", 3) == 0 || strncmp(pt-3, "die", 3) == 0)
       ptreplace(pt-2, 2, "ying");
     else if(strncmp(pt-5, "begin", 5) == 0) ptinsert(pt, "ning");
@@ -618,7 +623,6 @@ char md[];
     else if(strncmp(pt-3, "run", 3) == 0) ptinsert(pt, "ning");
     else if(strncmp(pt-3, "sit", 3) == 0) ptinsert(pt, "ting");
     else if(strncmp(pt-3, "see", 3) == 0) ptinsert(pt, "ing");
-    else if(strncmp(pt-2, "be", 2) == 0) ptinsert(pt, "ing");
     else if(*(pt-1) == 'e') ptreplace(pt-1, 1, "ing");
     else ptinsert(pt, "ing");
 }
