@@ -122,7 +122,8 @@ srcUrl(){
       return;
     }
     if(strncmp(jps, "<!--", 4) == 0 && script == 0) return;
-//    if(strncmp(jps, "<?", 2) == 0) return;
+
+    if(strncmp(egs, "<?", 2) == 0) return;
 
     if(strstr(jps, "</STYLE>") || strstr(jps, "</style>")){
       style = 0;   return;
@@ -133,7 +134,7 @@ srcUrl(){
       style = 1;   return;
     }
 
-        if(Dbg == 'Y') fprintf(dbg, "-- srcURL -- path = %s jps = %s \n", path_base, jps);
+ if(Dbg == 'Y') fprintf(dbg, "-- srcURL -- path = %s jps = %s \n", path_base, jps);
     if((pt = (char*)strstr(egs, "src=")) || (pt = (char*)strstr(egs, "SRC="))
     || (pt = (char*)strstr(egs, "BACKGROUND=")) || (pt = (char*)strstr(egs, "swfpath")) ){
       if((pt1 = (char*)strstr(pt, "\"/")) && pt1 < pt + 13){
@@ -168,26 +169,43 @@ srcUrl(){
         return;
       }
     }
-    if(((pt = (char*)strstr(egs, "<meta ")) || (pt = (char*)strstr(egs, "<META "))) && (strstr(egs, "Refresh") || strstr(egs, "refresh"))){
-      if((pt1 = (char*)strchr(pt, '>'))){
-        ptinsert(pt1+1, "-->");
-        ptinsert(pt, "<!--");
-        return;
+    // <meta
+    if((pt = (char*)strstr(egs, "<meta ")) || (pt = (char*)strstr(egs, "<META "))){
+      if((pt = (char*)strstr(egs, "href=")) || (pt = (char*)strstr(egs, "HREF="))){
+        if((pt1 = (char*)strstr(pt, "\"/")) && pt1 < pt + 7){
+          ptreplace(pt1+1, 1, "");
+          ptinsert(pt1+1, path);
+ if(Dbg == 'Y') fprintf(dbg, "-- srcURL meta -- path = %s egs = %s \n", path, egs);
+          return;
+        }
+        if((pt1 = (char*)strchr(pt, '\"')) && pt1 < pt + 7){
+          if(strncmp(pt1+1, "http:", 5) == 0) return;
+          ptinsert(pt1+1, path);
+ if(Dbg == 'Y') fprintf(dbg, "-- srcURL meta -- path = %s egs = %s \n", path, egs);
+          return;
+        }
       }
+      if((strstr(egs, "Refresh") || strstr(egs, "refresh"))){
+        if((pt1 = (char*)strchr(pt, '>'))){
+          ptinsert(pt1+1, "-->");
+          ptinsert(pt, "<!--");
+          return;
+        }
+      }
+      return;
     }
     if((pt = (char*)strstr(egs, "<link ")) || (pt = (char*)strstr(egs, "<LINK "))){
       if((pt = (char*)strstr(egs, "href=")) || (pt = (char*)strstr(egs, "HREF="))){
         if((pt1 = (char*)strstr(pt, "\"/")) && pt1 < pt + 7){
           ptreplace(pt1+1, 1, "");
           ptinsert(pt1+1, path);
-          if(Dbg == 'Y') fprintf(dbg, "-- srcURL2 -- path = %s egs = %s \n", path, egs);
+ if(Dbg == 'Y') fprintf(dbg, "-- srcURL2 -- path = %s egs = %s \n", path, egs);
           return;
         }
         if((pt1 = (char*)strchr(pt, '\"')) && pt1 < pt + 7){
-          if(strncmp(pt1+1, "http:", 5) ){
+          if(strncmp(pt1+1, "http:", 5) == 0) return;
           ptinsert(pt1+1, path);
-          }
-          if(Dbg == 'Y') fprintf(dbg, "-- srcURL2 -- path = %s egs = %s \n", path, egs);
+ if(Dbg == 'Y') fprintf(dbg, "-- srcURL2 -- path = %s egs = %s \n", path, egs);
           return;
         }
       }
@@ -448,7 +466,7 @@ siage()
     if(pt) ptreplace(pt, 2, ". ");
     pt = (char*)strstr(egs, " ?");
     if(pt) ptreplace(pt, 2, "? ");
-    pt = (char*)strstr(egs, "is not");
+    pt = (char*)strstr(egs, "is not ");
     if(pt) ptreplace(pt, 6, "isn't");
     pt = (char*)strstr(egs, "was not");
     if(pt) ptreplace(pt, 7, "wasn't");
@@ -518,6 +536,7 @@ predit()
     if((pt = (char*)strstr(wdh, "")) && strncmp(pt+6, "", 4)) ptreplace(pt, 6, "");
     if((pt = (char*)strstr(wdh, "Ȃ̂")) && strncmp(pt-4, "", 4)) ptreplace(pt, 2, "ł");
     if(pt = (char*)strstr(wdh, "ɏ")) ptreplace(pt, 8, "̏");
+    if(pt = (char*)strstr(wdh, "")) ptreplace(pt, 8, "邯");
     if(pt = (char*)strstr(wdh, "̂")) ptreplace(pt, 8, "̌`");
     if(pt = (char*)strstr(wdh, "NȏO")) ptreplace(pt, 8, "NOȏ");
     if(pt = (char*)strstr(wdh, "ɂ͂܂")) ptreplace(pt, 4, "ɁA");
@@ -527,6 +546,7 @@ predit()
     if(pt = (char*)strstr(wdh, "̂ł")) ptreplace(pt, 4, "/");
     if(pt = (char*)strstr(wdh, "̂Ƃ킴")) ptreplace(pt, 4, "/");
     if(pt = (char*)strstr(wdh, "Ƃ")) ptreplace(pt, 8, "");
+    if(pt = (char*)strstr(wdh, "ł̂")) ptreplace(pt, 2, "ŁA");
     if(pt = (char*)strstr(wdh, "Ƃ͂Ă")) ptreplace(pt, 14, "A");
     if(strstr(wdh, "ǂꂭ炢") && (pt = (char*)strstr(wdh, "B")))
       ptreplace(pt, 2, "H");
